pub struct AgentExecutor<'a> { /* private fields */ }Expand description
Executor for agent (AI) steps.
Runs an AI agent with the given prompt and configuration, capturing the response value, cost, and token counts.
Implementations
Sourceimpl<'a> AgentExecutor<'a>
impl<'a> AgentExecutor<'a>
Sourcepub fn new(config: &'a AgentStepConfig) -> Self
pub fn new(config: &'a AgentStepConfig) -> Self
Create a new agent executor from a config reference.