pub struct ShellExecutor<'a> { /* private fields */ }Expand description
Executor for shell steps.
Runs a shell command and captures stdout, stderr, and exit code.
Implementations
Sourceimpl<'a> ShellExecutor<'a>
impl<'a> ShellExecutor<'a>
Sourcepub fn new(config: &'a ShellConfig) -> Self
pub fn new(config: &'a ShellConfig) -> Self
Create a new shell executor from a config reference.