pub struct OperationContext { /* private fields */ }Expand description
Context provided to every Operation::execute call.
Carries a shared HTTP client and a secret resolver so that operations do not need to manage their own connections or credentials.
Examples
use ironflow_core::operation::{OperationContext, NoopSecretResolver};
use std::sync::Arc;
let ctx = OperationContext::new(Arc::new(NoopSecretResolver));
let _client = ctx.http_client();Implementations
Sourceimpl OperationContext
impl OperationContext
Sourcepub fn new(secrets: Arc<dyn SecretResolver>) -> OperationContext
pub fn new(secrets: Arc<dyn SecretResolver>) -> OperationContext
Create a new context with a default HTTP client.
Examples
use ironflow_core::operation::{OperationContext, NoopSecretResolver};
use std::sync::Arc;
let ctx = OperationContext::new(Arc::new(NoopSecretResolver));Sourcepub fn with_http_client(
http_client: Client,
secrets: Arc<dyn SecretResolver>,
) -> OperationContext
pub fn with_http_client( http_client: Client, secrets: Arc<dyn SecretResolver>, ) -> OperationContext
Create a new context with a custom HTTP client.
Use this to share a single Client across multiple operations
within the same workflow run.
Examples
use ironflow_core::operation::{OperationContext, NoopSecretResolver};
use reqwest::Client;
use std::sync::Arc;
let client = Client::new();
let ctx = OperationContext::with_http_client(client, Arc::new(NoopSecretResolver));Sourcepub fn http_client(&self) -> &Client
pub fn http_client(&self) -> &Client
The shared HTTP client for this operation context.
Sourcepub fn secrets(&self) -> &dyn SecretResolver
pub fn secrets(&self) -> &dyn SecretResolver
The secret resolver for this operation context.