pub type HumanInputMock = Arc<dyn Fn(&str, &HumanInputConfig) -> HumanInputOutcome + Send + Sync>;Expand description
Closure answering a human input step from its name and config.
Aliased Type
pub struct HumanInputMock { /* private fields */ }pub type HumanInputMock = Arc<dyn Fn(&str, &HumanInputConfig) -> HumanInputOutcome + Send + Sync>;Closure answering a human input step from its name and config.
pub struct HumanInputMock { /* private fields */ }