pub struct HttpConfig {
pub method: String,
pub url: String,
pub headers: Vec<(String, String)>,
pub body: Option<Value>,
pub timeout_secs: Option<u64>,
pub allow_failure: bool,
}Expand description
Serializable configuration for an HTTP step.
Examples
use ironflow_engine::config::HttpConfig;
let config = HttpConfig::get("https://api.example.com/health");Fields
method: StringHTTP method (GET, POST, PUT, PATCH, DELETE).
url: StringRequest URL.
headers: Vec<(String, String)>Request headers.
body: Option<Value>Request body as JSON.
timeout_secs: Option<u64>Timeout in seconds (default: 30).
allow_failure: boolWhen true, a failure of this step does not fail the run.
Implementations
Sourceimpl HttpConfig
impl HttpConfig
Sourcepub fn get(url: &str) -> Self
pub fn get(url: &str) -> Self
Create a GET request config.
Examples
use ironflow_engine::config::HttpConfig;
let config = HttpConfig::get("https://example.com");
assert_eq!(config.method, "GET");Sourcepub fn timeout_secs(self, secs: u64) -> Self
pub fn timeout_secs(self, secs: u64) -> Self
Set the timeout in seconds.
Sourcepub fn allow_failure(self) -> Self
pub fn allow_failure(self) -> Self
Mark this step as allowed to fail without stopping the run.
Examples
use ironflow_engine::config::HttpConfig;
let config = HttpConfig::get("https://example.com").allow_failure();
assert!(config.allow_failure);Trait Implementations
Sourceimpl Clone for HttpConfig
impl Clone for HttpConfig
Sourcefn clone(&self) -> HttpConfig
fn clone(&self) -> HttpConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HttpConfig
impl Debug for HttpConfig
Sourceimpl<'de> Deserialize<'de> for HttpConfig
impl<'de> Deserialize<'de> for HttpConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<HttpConfig> for StepConfig
impl From<HttpConfig> for StepConfig
Sourcefn from(c: HttpConfig) -> Self
fn from(c: HttpConfig) -> Self
Converts to this type from the input type.